Buildroot overrides — bodhi 4.0.0 documentation

# Buildroot overrides

## Python objects

Message schema for Buildroot Overrides.

Each message is defined as a Python class. For details, see fedora-messaging documentation on messages.

class `bodhi.messages.schemas.buildroot_override.` `BuildrootOverrideMessage`(body=None, headers=None, topic=None, properties=None, severity=None)

  Bases: `bodhi.messages.schemas.base.BodhiMessage`

  Base class for the buildroot_override messages.

  `agent`

    Return the agent’s username for this message.

    Returns: | The agent’s username.

  `build`

    Return the build that was overridden.

  `packages`

    List of packages affected by the action that generated this message.

    Returns: | A list of affected package names.

  `submitter`

    Return the name of the submitter for the override.

  `summary`

    Return a short, human-readable representation of this message.

    This should provide a short summary of the message, much like the subject line of an email.

  `url`

    Return a URL to the action that caused this message to be emitted.

    Returns: | A relevant URL.

  `usernames`

    List of users affected by the action that generated this message.

    Returns: | A list of affected usernames.

class `bodhi.messages.schemas.buildroot_override.` `BuildrootOverrideTagV1`(body=None, headers=None, topic=None, properties=None, severity=None)

  Bases: `bodhi.messages.schemas.buildroot_override.BuildrootOverrideMessage`

  Sent when a buildroot override is added and tagged into the build root.

  `topic` = 'bodhi.buildroot_override.tag'

class `bodhi.messages.schemas.buildroot_override.` `BuildrootOverrideUntagV1`(body=None, headers=None, topic=None, properties=None, severity=None)

  Bases: `bodhi.messages.schemas.buildroot_override.BuildrootOverrideMessage`

  Sent when a buildroot override is untagged from the build root.

  `topic` = 'bodhi.buildroot_override.untag'

## JSON schemas

### bodhi.buildroot_override.tag

    {
        "id": "https://bodhi.fedoraproject.org/message-schemas/v1/bodhi.buildroot_override.tag#",
        "$schema": "http://json-schema.org/draft-04/schema#",
        "description": "Schema for message sent when buildroot overrides are tagged",
        "type": "object",
        "properties": {
            "override": {
                "type": "object",
                "properties": {
                    "nvr": {
                        "type": "string",
                        "description": "The NVR of the build that was overridden"
                    },
                    "submitter": {
                        "type": "object",
                        "description": "The user that submitted the override",
                        "properties": {
                            "name": {
                                "type": "string",
                                "description": "The user's account name"
                            }
                        },
                        "required": [
                            "name"
                        ]
                    }
                },
                "required": [
                    "nvr",
                    "submitter"
                ]
            }
        },
        "required": [
            "override"
        ]
    }

### bodhi.buildroot_override.untag

    {
        "id": "https://bodhi.fedoraproject.org/message-schemas/v1/bodhi.buildroot_override.untag#",
        "$schema": "http://json-schema.org/draft-04/schema#",
        "description": "Schema for message sent when buildroot overrides are untagged",
        "type": "object",
        "properties": {
            "override": {
                "type": "object",
                "properties": {
                    "nvr": {
                        "type": "string",
                        "description": "The NVR of the build that had been overridden"
                    },
                    "submitter": {
                        "type": "object",
                        "description": "The user that submitted the override",
                        "properties": {
                            "name": {
                                "type": "string",
                                "description": "The user's account name"
                            }
                        },
                        "required": [
                            "name"
                        ]
                    }
                },
                "required": [
                    "nvr",
                    "submitter"
                ]
            }
        },
        "required": [
            "override"
        ]
    }